<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\workspace_approval\Entity\WorkspaceApprovalRequest;
use Drupal\workspaces\WorkspaceInterface;

/**
 * Provides a confirmation form to approve an approval request.
 */
final class WorkspaceApprovalRequestApproveForm extends WorkspaceApprovalRequestConfirmForm {

  /**
   * {@inheritdoc}
   */
  protected $operation = 'approve';

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    return $this->t('Approve this %title?', [
      '%title' => $this->getBundleEntity()?->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TranslatableMarkup {
    return $this->t("This action will allow this content to transition to its next workflow state.");
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl(): Url {
    return Url::fromUserInput($this->getRedirectDestination()->get())->setAbsolute();
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);
    \assert($this->entity instanceof WorkspaceApprovalRequest);
    $this->entity->set('approved', TRUE);
    $this->entity->validate();
    $this->entity->save();
    $workspace = $this->entity->getSubject();
    \assert($workspace instanceof WorkspaceInterface);
    $form_state->setRedirectUrl(Url::fromRoute(
      'entity.workspace_approval_request.list.workspace',
      ['workspace' => $workspace->id()],
    ));

    $entityStorage = $this->entityTypeManager->getStorage('workspace_approval_request');
    $pending_review_count = $entityStorage->getQuery('OR')
      ->accessCheck(TRUE)
      ->condition('approved', FALSE)
      ->condition('approved', NULL, 'IS NULL')
      ->count()->execute();

    if ($pending_review_count > 0) {
      $this->messenger()->addWarning($this->t('This workspace cannot be transitioned until all pending review requests have been approved.'));
      return;
    }
  }

}
