<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\workspace_approval\WorkspaceApprovalRequestInterface;
use Drupal\workspaces\WorkspaceInterface;

/**
 * Provides a confirmation form to dismiss an approval request.
 */
final class WorkspaceApprovalRequestDismissForm extends WorkspaceApprovalRequestConfirmForm {

  /**
   * {@inheritdoc}
   */
  protected $operation = 'dismiss';

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    return $this->t('Dismiss this %title?', [
      '%title' => $this->getBundleEntity()?->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TranslatableMarkup {
    return $this->t("This action will prevent this review from blocking a transition to its next workflow state.");
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl(): Url {
    return Url::fromUserInput($this->getRedirectDestination()->get())->setAbsolute();
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);
    \assert($this->entity instanceof WorkspaceApprovalRequestInterface);
    $this->entity->setUnpublished();
    $this->entity->validate();
    $this->entity->save();
    $workspace = $this->entity->getSubject();
    \assert($workspace instanceof WorkspaceInterface);
    $form_state->setRedirectUrl(Url::fromRoute(
      'entity.workspace_approval_request.list.workspace',
      ['workspace' => $workspace->id()],
    ));
  }

}
