<?php

declare(strict_types=1);

namespace Drupal\workspace_approval;

use Drupal\Core\Entity\Sql\SqlContentEntityStorage;

/**
 * Storage handler for workspace_approval_request entities.
 */
final class WorkspaceApprovalRequestStorage extends SqlContentEntityStorage implements WorkspaceApprovalRequestStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function getApprovalRequests(?string $transition_id = NULL, ?string $subject_id = NULL): array {
    $query = $this->getQuery()->accessCheck(FALSE);
    if ($transition_id !== NULL) {
      $bundles = $this->entityTypeManager->getStorage('workspace_approval_request_type')->getQuery()
        ->condition('transition', $transition_id)
        ->accessCheck(FALSE)
        ->execute();
      // If there are no bundles guarding this transition, then there can be no
      // requests.
      if (empty($bundles)) {
        return [];
      }
      $query->condition('bundle', $bundles, 'IN');
    }
    if (!\is_null($subject_id)) {
      $query->condition('subject', $subject_id);
    }
    return $this->loadMultiple($query->execute());
  }

}
